
# Getting Started with Cypress Test API

## Introduction

This is a sample API to demonstrate an OpenAPI spec with multiple endpoints and a custom model.

## Install the Package

The package is compatible with Python versions `3.7+`.
Install the package from PyPi using the following pip command:

```bash
pip install cameran-koch-sdk==1.1.1
```

You can also view the package at:
https://pypi.python.org/pypi/cameran-koch-sdk/1.1.1

## Test the SDK

You can test the generated SDK and the server with test cases. `unittest` is used as the testing framework and `pytest` is used as the test runner. You can run the tests as follows:

Navigate to the root directory of the SDK and run the following commands

```
pip install -r test-requirements.txt
pytest
```

## Initialize the API Client

**_Note:_** Documentation for the client can be found [here.](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/client.md)

The following parameters are configurable for the API Client:

| Parameter | Type | Description |
|  --- | --- | --- |
| http_client_instance | `HttpClient` | The Http Client passed from the sdk user for making requests |
| override_http_client_configuration | `bool` | The value which determines to override properties of the passed Http Client from the sdk user |
| http_call_back | `HttpCallBack` | The callback value that is invoked before and after an HTTP call is made to an endpoint |
| timeout | `float` | The value to use for connection timeout. <br> **Default: 60** |
| max_retries | `int` | The number of times to retry an endpoint call if it fails. <br> **Default: 0** |
| backoff_factor | `float` | A backoff factor to apply between attempts after the second try. <br> **Default: 2** |
| retry_statuses | `Array of int` | The http statuses on which retry is to be done. <br> **Default: [413, 503, 504]** |
| retry_methods | `Array of string` | The http methods on which retry is to be done. <br> **Default: ['GET', 'PUT', 'POST']** |
| logging_configuration | [`LoggingConfiguration`](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/logging-configuration.md) | The SDK logging configuration for API calls |

The API client can be initialized as follows:

```python
client = CypresstestapiClient(
    environment=Environment.PRODUCTION,
    logging_configuration=LoggingConfiguration(
        log_level=logging.INFO,
        request_logging_config=RequestLoggingConfiguration(
            log_body=True
        ),
        response_logging_config=ResponseLoggingConfiguration(
            log_headers=True
        )
    )
)
```

## List of APIs

* [API](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/controllers/api.md)

## SDK Infrastructure

### Configuration

* [AbstractLogger](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/abstract-logger.md)
* [LoggingConfiguration](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/logging-configuration.md)
* [RequestLoggingConfiguration](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/request-logging-configuration.md)
* [ResponseLoggingConfiguration](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/response-logging-configuration.md)

### HTTP

* [HttpResponse](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/http-response.md)
* [HttpRequest](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/http-request.md)

### Utilities

* [ApiResponse](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/api-response.md)
* [ApiHelper](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/api-helper.md)
* [HttpDateTime](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/http-date-time.md)
* [RFC3339DateTime](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/rfc3339-date-time.md)
* [UnixDateTime](https://www.github.com/ZahraN444/cameran-koch-python-sdk/tree/1.1.1/doc/unix-date-time.md)

